@@ -20,10 +20,11 @@
  */
 package org.apache.qpid.server.security.auth.database;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.fail;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertThrows;
+import static org.junit.jupiter.api.Assertions.fail;
 
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 import org.apache.qpid.test.utils.UnitTestBase;
 
@@ -33,29 +34,23 @@ import org.apache.qpid.test.utils.UnitTestBase;
  */
 public class PlainUserTest extends UnitTestBase
 {
-
     private final String USERNAME = "username";
     private final String PASSWORD = "password";
 
     @Test
     public void testTooLongArrayConstructor()
     {
-        try
-        {
-            PlainUser user = new PlainUser(new String[]{USERNAME, PASSWORD, USERNAME}, null);
-            fail("Error expected");
-        }
-        catch (IllegalArgumentException e)
-        {
-            assertEquals("User Data should be length 2, username, password", e.getMessage());
-        }
+        final IllegalArgumentException thrown = assertThrows(IllegalArgumentException.class,
+                () -> new PlainUser(new String[]{USERNAME, PASSWORD, USERNAME}, null),
+                "Error expected");
+        assertEquals("User Data should be length 2, username, password", thrown.getMessage());
     }
 
     @Test
     public void testStringArrayConstructor()
     {
-        PlainUser user = new PlainUser(new String[]{USERNAME, PASSWORD}, null);
-        assertEquals("Username incorrect", USERNAME, user.getName());
+        final PlainUser user = new PlainUser(new String[]{USERNAME, PASSWORD}, null);
+        assertEquals(USERNAME, user.getName(), "Username incorrect");
         int index = 0;
 
         char[] password = PASSWORD.toCharArray();
@@ -64,7 +59,7 @@ public class PlainUserTest extends UnitTestBase
         {
             for (byte c : user.getEncodedPassword())
             {
-                assertEquals("Password incorrect", (long) password[index], (long) (char) c);
+                assertEquals(password[index], (long) (char) c, "Password incorrect");
                 index++;
             }
         }
@@ -78,7 +73,7 @@ public class PlainUserTest extends UnitTestBase
         index=0;
         for (char c : user.getPassword())
         {
-            assertEquals("Password incorrect", (long) password[index], (long) c);
+            assertEquals(password[index], (long) c, "Password incorrect");
             index++;
         }
     }
