@@ -20,11 +20,10 @@ package org.apache.qpid.server.security.auth.manager;
 
 import static java.nio.charset.StandardCharsets.UTF_8;
 import static org.apache.qpid.server.security.auth.manager.CachingAuthenticationProvider.AUTHENTICATION_CACHE_MAX_SIZE;
-import static org.hamcrest.CoreMatchers.not;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.fail;
-import static org.junit.Assume.assumeThat;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertThrows;
+import static org.junit.jupiter.api.Assumptions.assumeFalse;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.when;
 
@@ -36,12 +35,11 @@ import java.nio.file.Path;
 import java.security.Principal;
 import java.security.PrivilegedAction;
 import java.util.ArrayList;
-import java.util.Collections;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
+import java.util.Objects;
 import java.util.Set;
-import java.util.UUID;
 import java.util.concurrent.atomic.AtomicBoolean;
 
 import javax.security.auth.Subject;
@@ -60,7 +58,6 @@ import org.apache.directory.server.core.annotations.ApplyLdifFiles;
 import org.apache.directory.server.core.annotations.CreateDS;
 import org.apache.directory.server.core.annotations.CreatePartition;
 import org.apache.directory.server.core.api.DirectoryService;
-import org.apache.directory.server.core.integ.CreateLdapServerRule;
 import org.apache.directory.server.core.kerberos.KeyDerivationInterceptor;
 import org.apache.directory.server.factory.ServerAnnotationProcessor;
 import org.apache.directory.server.kerberos.kdc.KdcServer;
@@ -73,10 +70,11 @@ import org.apache.directory.server.ldap.handlers.sasl.plain.PlainMechanismHandle
 import org.apache.directory.shared.kerberos.KerberosTime;
 import org.apache.directory.shared.kerberos.codec.types.EncryptionType;
 import org.apache.directory.shared.kerberos.components.EncryptionKey;
-import org.junit.After;
-import org.junit.Before;
-import org.junit.ClassRule;
-import org.junit.Test;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
+
+import org.junit.jupiter.api.extension.RegisterExtension;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -87,6 +85,7 @@ import org.apache.qpid.server.security.auth.AuthenticationResult;
 import org.apache.qpid.server.security.auth.SocketConnectionPrincipal;
 import org.apache.qpid.server.security.auth.sasl.SaslNegotiator;
 import org.apache.qpid.server.security.auth.sasl.SaslSettings;
+import org.apache.qpid.test.utils.CreateLdapServerExtension;
 import org.apache.qpid.test.utils.JvmVendor;
 import org.apache.qpid.server.test.KerberosUtilities;
 import org.apache.qpid.test.utils.SystemPropertySetter;
@@ -94,38 +93,38 @@ import org.apache.qpid.test.utils.TestFileUtils;
 import org.apache.qpid.test.utils.UnitTestBase;
 
 @CreateDS(
-        name = "testDS",
-        partitions =
-                {
-                        @CreatePartition(name = "test", suffix = "dc=qpid,dc=org")
-                },
-        additionalInterceptors =
-                {
-                        KeyDerivationInterceptor.class
-                }
+    name = "testDS",
+    partitions =
+    {
+        @CreatePartition(name = "test", suffix = "dc=qpid,dc=org")
+    },
+    additionalInterceptors =
+    {
+        KeyDerivationInterceptor.class
+    }
 )
 @CreateLdapServer(
-        transports =
-                {
-                        @CreateTransport(protocol = "LDAP")
-                },
-        allowAnonymousAccess = true,
-        saslHost = "localhost",
-        saslPrincipal = "ldap/localhost@QPID.ORG",
-        saslMechanisms =
-                {
-                        @SaslMechanism(name = SupportedSaslMechanisms.PLAIN, implClass = PlainMechanismHandler.class),
-                        @SaslMechanism(name = SupportedSaslMechanisms.GSSAPI, implClass = GssapiMechanismHandler.class)
-                }
+    transports =
+    {
+        @CreateTransport(protocol = "LDAP")
+    },
+    allowAnonymousAccess = true,
+    saslHost = "localhost",
+    saslPrincipal = "ldap/localhost@QPID.ORG",
+    saslMechanisms =
+    {
+        @SaslMechanism(name = SupportedSaslMechanisms.PLAIN, implClass = PlainMechanismHandler.class),
+        @SaslMechanism(name = SupportedSaslMechanisms.GSSAPI, implClass = GssapiMechanismHandler.class)
+    }
 )
 @CreateKdcServer(
-        transports =
-                {
-                        @CreateTransport(protocol = "TCP", port = 0)
-                },
-        kdcPrincipal="krbtgt/QPID.ORG@QPID.ORG",
-        primaryRealm="QPID.ORG",
-        searchBaseDn = "ou=users,dc=qpid,dc=org")
+    transports =
+    {
+        @CreateTransport(protocol = "TCP", port = 0)
+    },
+    kdcPrincipal="krbtgt/QPID.ORG@QPID.ORG",
+    primaryRealm="QPID.ORG",
+    searchBaseDn = "ou=users,dc=qpid,dc=org")
 @ApplyLdifFiles("users.ldif")
 public class SimpleLDAPAuthenticationManagerTest extends UnitTestBase
 {
@@ -138,6 +137,8 @@ public class SimpleLDAPAuthenticationManagerTest extends UnitTestBase
     private static final String USER_1_NAME = "test1";
     private static final String USER_1_PASSWORD = "password1";
     private static final String USER_1_DN = "cn=integration-test1,ou=users,dc=qpid,dc=org";
+    private static final String USER_2_NAME = "test2";
+    private static final String USER_2_PASSWORD = "password2";
     private static final String GROUP_SEARCH_CONTEXT_VALUE = "ou=groups,dc=qpid,dc=org";
     private static final String GROUP_SEARCH_FILTER_VALUE = "(member={0})";
     private static final String LDAP_SERVICE_NAME = "ldap";
@@ -149,21 +150,21 @@ public class SimpleLDAPAuthenticationManagerTest extends UnitTestBase
     private static final AtomicBoolean KERBEROS_SETUP = new AtomicBoolean();
     private static final KerberosUtilities UTILS = new KerberosUtilities();
 
-    @ClassRule
-    public static CreateLdapServerRule LDAP = new CreateLdapServerRule();
+    @RegisterExtension
+    public static CreateLdapServerExtension LDAP = new CreateLdapServerExtension();
 
-    @ClassRule
+    @RegisterExtension
     public static final SystemPropertySetter SYSTEM_PROPERTY_SETTER = new SystemPropertySetter();
 
-    private SimpleLDAPAuthenticationManager _authenticationProvider;
+    private SimpleLDAPAuthenticationManager<?> _authenticationProvider;
 
-    @Before
+    @BeforeEach
     public void setUp()
     {
         _authenticationProvider = createAuthenticationProvider();
     }
 
-    @After
+    @AfterEach
     public void tearDown()
     {
         if (_authenticationProvider != null)
@@ -194,29 +195,25 @@ public class SimpleLDAPAuthenticationManagerTest extends UnitTestBase
         when(saslSettings.getLocalFQDN()).thenReturn(HOSTNAME);
 
         final SaslNegotiator negotiator = _authenticationProvider.createSaslNegotiator("PLAIN", saslSettings, null);
-        assertNotNull("Could not create SASL negotiator for mechanism 'PLAIN'", negotiator);
+        assertNotNull(negotiator, "Could not create SASL negotiator for mechanism 'PLAIN'");
 
         final AuthenticationResult result = negotiator.handleResponse(new byte[0]);
-        assertEquals("Unexpected authentication status",
-                     AuthenticationResult.AuthenticationStatus.CONTINUE,
-                     result.getStatus());
+        assertEquals(AuthenticationResult.AuthenticationStatus.CONTINUE, result.getStatus(),
+                "Unexpected authentication status");
 
         final AuthenticationResult result2 =
                 negotiator.handleResponse(String.format("\0%s\0%s", USER_1_NAME, USER_1_PASSWORD).getBytes(UTF_8));
 
-        assertEquals("Unexpected authentication status",
-                     AuthenticationResult.AuthenticationStatus.SUCCESS,
-                     result2.getStatus());
+        assertEquals(AuthenticationResult.AuthenticationStatus.SUCCESS, result2.getStatus(),
+                "Unexpected authentication status");
     }
 
     @Test
     public void testGroups()
     {
-        _authenticationProvider.close();
-        final Map<String, Object> groupSetUp = new HashMap<>();
-        groupSetUp.put(SimpleLDAPAuthenticationManager.GROUP_SEARCH_CONTEXT, GROUP_SEARCH_CONTEXT_VALUE);
-        groupSetUp.put(SimpleLDAPAuthenticationManager.GROUP_SEARCH_FILTER, GROUP_SEARCH_FILTER_VALUE);
-        _authenticationProvider = createAuthenticationProvider(groupSetUp);
+        final Map<String, Object> groupSetUp = Map.of(SimpleLDAPAuthenticationManager.GROUP_SEARCH_CONTEXT, GROUP_SEARCH_CONTEXT_VALUE,
+                SimpleLDAPAuthenticationManager.GROUP_SEARCH_FILTER, GROUP_SEARCH_FILTER_VALUE);
+        _authenticationProvider.setAttributes(groupSetUp);
 
         final AuthenticationResult result = _authenticationProvider.authenticate(USER_1_NAME, USER_1_PASSWORD);
         assertEquals(AuthenticationResult.AuthenticationStatus.SUCCESS, result.getStatus());
@@ -226,25 +223,23 @@ public class SimpleLDAPAuthenticationManagerTest extends UnitTestBase
         assertNotNull(principals);
 
         final Principal groupPrincipal = principals.stream()
-                                                   .filter(p -> "cn=group1,ou=groups,dc=qpid,dc=org".equalsIgnoreCase(p.getName()))
-                                                   .findFirst()
-                                                   .orElse(null);
+                .filter(p -> "cn=group1,ou=groups,dc=qpid,dc=org".equalsIgnoreCase(p.getName()))
+                .findFirst()
+                .orElse(null);
         assertNotNull(groupPrincipal);
     }
 
     @Test
     public void testAuthenticateSuccessWhenCachingEnabled()
     {
-        _authenticationProvider.close();
-        _authenticationProvider = createCachingAuthenticationProvider();
+        final Map<String, String> context = Map.of(AUTHENTICATION_CACHE_MAX_SIZE, "1");
+        _authenticationProvider.setAttributes(Map.of(SimpleLDAPAuthenticationManager.CONTEXT, context));
 
         final SocketConnectionPrincipal principal = mock(SocketConnectionPrincipal.class);
         when(principal.getRemoteAddress()).thenReturn(new InetSocketAddress(HOSTNAME, 5672));
-        final Subject subject =
-                new Subject(true, Collections.singleton(principal), Collections.emptySet(), Collections.emptySet());
-        final AuthenticationResult result = Subject.doAs(subject,
-                                                         (PrivilegedAction<AuthenticationResult>) () -> _authenticationProvider
-                                                                 .authenticate(USER_1_NAME, USER_1_PASSWORD));
+        final Subject subject = new Subject(true, Set.of(principal), Set.of(), Set.of());
+        final AuthenticationResult result = Subject.doAs(subject, (PrivilegedAction<AuthenticationResult>) () ->
+                _authenticationProvider.authenticate(USER_1_NAME, USER_1_PASSWORD));
         assertEquals(AuthenticationResult.AuthenticationStatus.SUCCESS, result.getStatus());
         assertEquals(USER_1_DN, result.getMainPrincipal().getName());
     }
@@ -254,9 +249,8 @@ public class SimpleLDAPAuthenticationManagerTest extends UnitTestBase
     {
         setUpKerberosAndJaas();
 
-        final Map<String, Object> attributes = new HashMap<>();
-        attributes.put(SimpleLDAPAuthenticationManager.AUTHENTICATION_METHOD, LdapAuthenticationMethod.GSSAPI.name());
-        attributes.put(SimpleLDAPAuthenticationManager.LOGIN_CONFIG_SCOPE, LOGIN_SCOPE);
+        final Map<String, Object> attributes = Map.of(SimpleLDAPAuthenticationManager.AUTHENTICATION_METHOD, LdapAuthenticationMethod.GSSAPI.name(),
+                SimpleLDAPAuthenticationManager.LOGIN_CONFIG_SCOPE, LOGIN_SCOPE);
         final SimpleLDAPAuthenticationManagerImpl authenticationProvider = createAuthenticationProvider(attributes);
         final AuthenticationResult result = authenticationProvider.authenticate(USER_1_NAME, USER_1_PASSWORD);
         assertEquals(AuthenticationResult.AuthenticationStatus.SUCCESS, result.getStatus());
@@ -268,9 +262,8 @@ public class SimpleLDAPAuthenticationManagerTest extends UnitTestBase
     {
         setUpKerberosAndJaas();
 
-        final Map<String, Object> attributes = new HashMap<>();
-        attributes.put(SimpleLDAPAuthenticationManager.AUTHENTICATION_METHOD, LdapAuthenticationMethod.GSSAPI.name());
-        attributes.put(SimpleLDAPAuthenticationManager.LOGIN_CONFIG_SCOPE, LOGIN_SCOPE);
+        final Map<String, Object> attributes = Map.of(SimpleLDAPAuthenticationManager.AUTHENTICATION_METHOD, LdapAuthenticationMethod.GSSAPI.name(),
+                SimpleLDAPAuthenticationManager.LOGIN_CONFIG_SCOPE, LOGIN_SCOPE);
         _authenticationProvider.setAttributes(attributes);
 
         final AuthenticationResult result = _authenticationProvider.authenticate(USER_1_NAME, USER_1_PASSWORD);
@@ -283,18 +276,12 @@ public class SimpleLDAPAuthenticationManagerTest extends UnitTestBase
     {
         setUpKerberosAndJaas();
 
-        final Map<String, Object> attributes = new HashMap<>();
-        attributes.put(SimpleLDAPAuthenticationManager.AUTHENTICATION_METHOD, LdapAuthenticationMethod.GSSAPI.name());
-        attributes.put(SimpleLDAPAuthenticationManager.LOGIN_CONFIG_SCOPE, "non-existing");
-        try
-        {
-            _authenticationProvider.setAttributes(attributes);
-            fail("Exception is expected");
-        }
-        catch (IllegalConfigurationException e)
-        {
-            // pass
-        }
+        final Map<String, Object> attributes = Map.of(SimpleLDAPAuthenticationManager.AUTHENTICATION_METHOD, LdapAuthenticationMethod.GSSAPI.name(),
+                SimpleLDAPAuthenticationManager.LOGIN_CONFIG_SCOPE, "non-existing");
+
+        assertThrows(IllegalConfigurationException.class,
+                () -> _authenticationProvider.setAttributes(attributes),
+                "Exception is expected");
     }
 
     @Test
@@ -302,18 +289,12 @@ public class SimpleLDAPAuthenticationManagerTest extends UnitTestBase
     {
         setUpKerberosAndJaas();
 
-        final Map<String, Object> attributes = new HashMap<>();
-        attributes.put(SimpleLDAPAuthenticationManager.AUTHENTICATION_METHOD, LdapAuthenticationMethod.GSSAPI.name());
-        attributes.put(SimpleLDAPAuthenticationManager.LOGIN_CONFIG_SCOPE, "ldap-gssapi-bind-broken");
-        try
-        {
-            _authenticationProvider.setAttributes(attributes);
-            fail("Exception is expected");
-        }
-        catch (IllegalConfigurationException e)
-        {
-            // pass
-        }
+        final Map<String, Object> attributes = Map.of(SimpleLDAPAuthenticationManager.AUTHENTICATION_METHOD, LdapAuthenticationMethod.GSSAPI.name(),
+                SimpleLDAPAuthenticationManager.LOGIN_CONFIG_SCOPE, "ldap-gssapi-bind-broken");
+
+        assertThrows(IllegalConfigurationException.class,
+                () -> _authenticationProvider.setAttributes(attributes),
+                "Exception is expected");
     }
 
     @Test
@@ -321,8 +302,8 @@ public class SimpleLDAPAuthenticationManagerTest extends UnitTestBase
     {
         setUpKerberosAndJaas();
 
-        final Map<String, Object> attributes = new HashMap<>();
-        attributes.put(SimpleLDAPAuthenticationManager.AUTHENTICATION_METHOD, LdapAuthenticationMethod.GSSAPI.name());
+        final Map<String, Object> attributes = Map.of(SimpleLDAPAuthenticationManager.AUTHENTICATION_METHOD,
+                LdapAuthenticationMethod.GSSAPI.name());
         _authenticationProvider.setAttributes(attributes);
 
         final AuthenticationResult result = _authenticationProvider.authenticate(USER_1_NAME, USER_1_PASSWORD);
@@ -330,17 +311,27 @@ public class SimpleLDAPAuthenticationManagerTest extends UnitTestBase
         assertEquals(USER_1_DN, result.getMainPrincipal().getName());
     }
 
-    private SimpleLDAPAuthenticationManagerImpl createAuthenticationProvider()
+    @Test
+    public void extractUserCN()
     {
-        return createAuthenticationProvider(Collections.emptyMap());
+        _authenticationProvider.setAttributes(Map.of("useFullLDAPName", "false"));
+        final AuthenticationResult result = _authenticationProvider.authenticate(USER_1_NAME, USER_1_PASSWORD);
+        assertEquals(AuthenticationResult.AuthenticationStatus.SUCCESS, result.getStatus());
+        assertEquals("integration-test1", result.getMainPrincipal().getName());
     }
 
-    private SimpleLDAPAuthenticationManagerImpl createCachingAuthenticationProvider()
+    @Test
+    public void extractInvalidUserCN()
     {
-        final Map<String, String> context = Collections.singletonMap(AUTHENTICATION_CACHE_MAX_SIZE, "1");
-        final Map<String, Object> attributes =
-                Collections.singletonMap(SimpleLDAPAuthenticationManager.CONTEXT, context);
-        return createAuthenticationProvider(attributes);
+        _authenticationProvider.setAttributes(Map.of("useFullLDAPName", "false"));
+        final AuthenticationResult result = _authenticationProvider.authenticate(USER_2_NAME, USER_2_PASSWORD);
+        assertEquals(AuthenticationResult.AuthenticationStatus.ERROR, result.getStatus());
+        assertEquals("Failed to extract CN from LDAP name 'uid=test2,ou=users,dc=qpid,dc=org'", result.getCause().getMessage());
+    }
+
+    private SimpleLDAPAuthenticationManagerImpl createAuthenticationProvider()
+    {
+        return createAuthenticationProvider(Map.of());
     }
 
     private SimpleLDAPAuthenticationManagerImpl createAuthenticationProvider(final Map<String, Object> settings)
@@ -352,8 +343,7 @@ public class SimpleLDAPAuthenticationManagerTest extends UnitTestBase
         attributes.put(SimpleLDAPAuthenticationManager.PROVIDER_URL,
                        String.format(LDAP_URL_TEMPLATE, LDAP.getLdapServer().getPort()));
         attributes.put(SimpleLDAPAuthenticationManager.SEARCH_FILTER, SEARCH_FILTER_VALUE);
-        attributes.put(SimpleLDAPAuthenticationManager.CONTEXT,
-                       Collections.singletonMap(AUTHENTICATION_CACHE_MAX_SIZE, "0"));
+        attributes.put(SimpleLDAPAuthenticationManager.CONTEXT, Map.of(AUTHENTICATION_CACHE_MAX_SIZE, "0"));
         attributes.putAll(settings);
         final SimpleLDAPAuthenticationManagerImpl authenticationProvider =
                 new SimpleLDAPAuthenticationManagerImpl(attributes, broker);
@@ -361,10 +351,9 @@ public class SimpleLDAPAuthenticationManagerTest extends UnitTestBase
         return authenticationProvider;
     }
 
-
     private void setUpKerberosAndJaas() throws Exception
     {
-        assumeThat(getJvmVendor(), not(JvmVendor.IBM));
+        assumeFalse(Objects.equals(getJvmVendor(), JvmVendor.IBM));
         if (KERBEROS_SETUP.compareAndSet(false, true))
         {
             setUpKerberos();
@@ -394,14 +383,13 @@ public class SimpleLDAPAuthenticationManagerTest extends UnitTestBase
         ldapServer.setSaslPrincipal(servicePrincipalName);
         ldapServer.setSearchBaseDn(USERS_DN);
 
-        createPrincipal("KDC", "KDC", "krbtgt", UUID.randomUUID().toString(), "krbtgt/" + REALM + "@" + REALM);
-        createPrincipal("Service", "LDAP Service", "ldap", UUID.randomUUID().toString(), servicePrincipalName);
+        createPrincipal("KDC", "KDC", "krbtgt", randomUUID().toString(), "krbtgt/" + REALM + "@" + REALM);
+        createPrincipal("Service", "LDAP Service", "ldap", randomUUID().toString(), servicePrincipalName);
     }
 
     private void setUpJaas() throws Exception
     {
         createKeyTab(BROKER_PRINCIPAL);
-
         UTILS.prepareConfiguration(KerberosUtilities.HOST_NAME, SYSTEM_PROPERTY_SETTER);
     }
 
@@ -449,7 +437,7 @@ public class SimpleLDAPAuthenticationManagerTest extends UnitTestBase
         directoryService.getAdminSession().add(entry);
     }
 
-    private void createPrincipal(String uid, String userPassword) throws LdapException
+    private void createPrincipal(final String uid, final String userPassword) throws LdapException
     {
         createPrincipal(uid, uid, uid, userPassword, uid + "@" + REALM);
     }
@@ -458,7 +446,7 @@ public class SimpleLDAPAuthenticationManagerTest extends UnitTestBase
     {
         final Keytab keytab = new Keytab();
         final List<KeytabEntry> entries = new ArrayList<>();
-        final String password = UUID.randomUUID().toString();
+        final String password = randomUUID().toString();
         for (final String principal : principals)
         {
             createPrincipal(principal, password);
@@ -475,7 +463,7 @@ public class SimpleLDAPAuthenticationManagerTest extends UnitTestBase
         keytab.write(keyTabFile);
     }
 
-    private void createKeyTab(String... principals) throws LdapException, IOException
+    private void createKeyTab(final String... principals) throws LdapException, IOException
     {
         final File keyTabFile = createFile("kerberos", ".keytab");
         createPrincipal(keyTabFile, principals);
