@@ -22,7 +22,6 @@ package org.apache.qpid.server.management.plugin.servlet.rest;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
-import java.io.UnsupportedEncodingException;
 import java.net.URLDecoder;
 import java.nio.charset.StandardCharsets;
 import java.util.ArrayList;
@@ -35,16 +34,18 @@ import java.util.List;
 import java.util.Map;
 import java.util.stream.Collectors;
 
-import javax.servlet.ServletConfig;
-import javax.servlet.ServletContext;
-import javax.servlet.ServletException;
-import javax.servlet.http.HttpServletRequest;
-import javax.servlet.http.HttpServletResponse;
-import javax.servlet.http.Part;
+import jakarta.servlet.ServletConfig;
+import jakarta.servlet.ServletContext;
+import jakarta.servlet.ServletException;
+import jakarta.servlet.http.HttpServletRequest;
+import jakarta.servlet.http.HttpServletResponse;
+import jakarta.servlet.http.Part;
 
 import com.fasterxml.jackson.databind.ObjectMapper;
 import com.fasterxml.jackson.databind.SerializationFeature;
 import com.google.common.base.Strings;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import org.apache.qpid.server.management.plugin.HttpManagementUtil;
 import org.apache.qpid.server.management.plugin.ManagementController;
@@ -62,6 +63,7 @@ public class RestServlet extends AbstractServlet
 {
     private static final long serialVersionUID = 1L;
     private static final String APPLICATION_JSON = "application/json";
+    private static final Logger LOGGER = LoggerFactory.getLogger(RestServlet.class);
 
     private transient ManagementController _managementController;
 
@@ -120,6 +122,7 @@ public class RestServlet extends AbstractServlet
         }
         catch (ManagementException e)
         {
+            LOGGER.error("Error when executing GET request", e);
             sendResponse(e, httpServletRequest, httpServletResponse);
         }
     }
@@ -139,6 +142,7 @@ public class RestServlet extends AbstractServlet
         }
         catch (ManagementException e)
         {
+            LOGGER.error("Error when executing POST request", e);
             sendResponse(e, httpServletRequest, httpServletResponse);
         }
     }
@@ -158,6 +162,7 @@ public class RestServlet extends AbstractServlet
         }
         catch (ManagementException e)
         {
+            LOGGER.error("Error when executing PUT request", e);
             sendResponse(e, httpServletRequest, httpServletResponse);
         }
     }
@@ -177,6 +182,7 @@ public class RestServlet extends AbstractServlet
         }
         catch (ManagementException e)
         {
+            LOGGER.error("Error when executing DELETE request", e);
             sendResponse(e, httpServletRequest, httpServletResponse);
         }
     }
@@ -193,9 +199,7 @@ public class RestServlet extends AbstractServlet
         setHeaders(response);
         setExceptionHeaders(managementException, response);
         response.setStatus(managementException.getStatusCode());
-        writeJsonResponse(Collections.singletonMap("errorMessage", managementException.getMessage()),
-                          request,
-                          response);
+        writeJsonResponse(Map.of("errorMessage", GENERIC_ERROR_MESSAGE), request, response);
     }
 
     private void setExceptionHeaders(final ManagementException managementException, final HttpServletResponse response)
@@ -299,7 +303,7 @@ public class RestServlet extends AbstractServlet
     {
         if (Strings.isNullOrEmpty(queryString))
         {
-            return Collections.emptyMap();
+            return Map.of();
         }
         Map<String, List<String>> query = new LinkedHashMap<>();
         final String[] pairs = queryString.split("&");
@@ -317,15 +321,8 @@ public class RestServlet extends AbstractServlet
 
             String key;
             String value;
-            try
-            {
-                key = URLDecoder.decode(pair.get(0), "UTF-8");
-                value = pair.get(1) == null ? null : URLDecoder.decode(pair.get(1), "UTF-8");
-            }
-            catch (UnsupportedEncodingException e)
-            {
-                throw new RuntimeException(e);
-            }
+            key = URLDecoder.decode(pair.get(0), StandardCharsets.UTF_8);
+            value = pair.get(1) == null ? null : URLDecoder.decode(pair.get(1), StandardCharsets.UTF_8);
             if (!query.containsKey(key))
             {
                 query.put(key, new ArrayList<>());
@@ -390,7 +387,7 @@ public class RestServlet extends AbstractServlet
 
         public Map<String, List<String>> getParameters()
         {
-            return Collections.unmodifiableMap(_query);
+            return _query;
         }
 
         @Override
