@@ -596,15 +596,14 @@ public class SpawnBrokerAdmin implements BrokerAdmin, Closeable
         {
             _currentWorkDirectory =
                     Files.createTempDirectory(String.format("qpid-work-%d-%s-%s-",
-                                                            _id,
-                                                            testClass.getSimpleName(),
-                                                            timestamp))
-                         .toString();
+                            _id,
+                            testClass.getSimpleName(),
+                            timestamp))
+                            .toString();
 
             String readyLogPattern = "BRK-1004 : Qpid Broker Ready";
 
             LOGGER.debug("Spawning broker working folder: {}", _currentWorkDirectory);
-
             int startUpTime = Integer.getInteger(SYSTEST_PROPERTY_SPAWN_BROKER_STARTUP_TIME, 30000);
 
             LOGGER.debug("Spawning broker permitted start-up time: {}", startUpTime);
@@ -905,7 +904,7 @@ public class SpawnBrokerAdmin implements BrokerAdmin, Closeable
         }
     }
 
-    private final class BrokerSystemOutputHandler implements Runnable
+    private static final class BrokerSystemOutputHandler implements Runnable
     {
         private final Logger LOGGER = LoggerFactory.getLogger(BrokerSystemOutputHandler.class);
 
@@ -1008,8 +1007,8 @@ public class SpawnBrokerAdmin implements BrokerAdmin, Closeable
 
     private static class ListeningPort
     {
-        private String _transport;
-        private int _port;
+        private final String _transport;
+        private final int _port;
 
         ListeningPort(final String transport, final int port)
         {
